BooleanKeySwitchingParameters

Struct BooleanKeySwitchingParameters 

pub struct BooleanKeySwitchingParameters {
    pub ks_base_log: DecompositionBaseLog,
    pub ks_level: DecompositionLevelCount,
}
A set of cryptographic parameters for homomorphic Boolean key switching.

Fields

ks_base_log: DecompositionBaseLogks_level: DecompositionLevelCount

Implementations

Source

impl BooleanKeySwitchingParameters

pub fn new( ks_base_log: DecompositionBaseLog, ks_level: DecompositionLevelCount, ) -> Self

Constructs a new set of parameters for boolean circuit evaluation.

Warning

Failing to fix the parameters properly would yield incorrect and insecure computation. Unless you are a cryptographer who really knows the impact of each of those parameters, you must stick with the provided parameters (if any), which both offer correct results with 128 bits of security.