pub struct EncryptionRandomGenerator<G: ByteRandomGenerator> { /* private fields */ }Expand description
A random number generator which can be used to encrypt messages.
Implementations
Sourceimpl<G: ByteRandomGenerator> EncryptionRandomGenerator<G>
impl<G: ByteRandomGenerator> EncryptionRandomGenerator<G>
Sourcepub fn new<S: Seeder + ?Sized>(
seed: impl Into<SeedKind>,
seeder: &mut S,
) -> Self
pub fn new<S: Seeder + ?Sized>( seed: impl Into<SeedKind>, seeder: &mut S, ) -> Self
Create a new EncryptionRandomGenerator, using the provided Seed or XofSeed
to seed the public mask generator and using the provided Seeder to privately seed the
noise generator.
Sourcepub fn remaining_bytes(&self) -> Option<usize>
pub fn remaining_bytes(&self) -> Option<usize>
Return the number of remaining bytes for the mask generator, if the generator is bounded.
pub fn noise_generator_mut(&mut self) -> &mut NoiseRandomGenerator<G>
pub fn mask_generator_mut(&mut self) -> &mut MaskRandomGenerator<G>
pub fn try_fork_from_config( &mut self, fork_config: EncryptionRandomGeneratorForkConfig, ) -> Result<impl Iterator<Item = Self>, ForkError>
Sourceimpl<G: ParallelByteRandomGenerator> EncryptionRandomGenerator<G>
impl<G: ParallelByteRandomGenerator> EncryptionRandomGenerator<G>
pub fn par_try_fork_from_config( &mut self, fork_config: EncryptionRandomGeneratorForkConfig, ) -> Result<impl IndexedParallelIterator<Item = Self>, ForkError>