pub struct TUniform<T: UnsignedInteger> { /* private fields */ }Expand description
The distribution $TUniform(1, -2^b, 2^b)$ is defined as follows, any value in the interval $\left[-2^b, 2^b\right]$ is selected with probability $\frac{1}{2^{b+1}}$, with the two end points $-2^b$ and $2^b$ being selected with probability $\frac{1}{2^{b+2}}$.
Implementations
Sourceimpl<T: UnsignedInteger> TUniform<T>
impl<T: UnsignedInteger> TUniform<T>
Sourcepub const fn new(bound_log2: u32) -> Self
pub const fn new(bound_log2: u32) -> Self
Construct a TUniform distribution see TUniform for behavior of randomly generated
values.
Panics
Panics if bound_log2 is greater than the Scalar type number of bits minus two.
The reason for this is that with a higher bound_log2 it is impossible to distinguish
between $-2^{bound_log2}$ and $2^{bound_log2}$ because of the 2’s complement
representation of integers.
Sourcepub const fn try_new(bound_log2: u32) -> Result<Self, &'static str>
pub const fn try_new(bound_log2: u32) -> Result<Self, &'static str>
Construct a TUniform distribution see TUniform for behavior of randomly generated
values.
Note
Returns an Err variant if bound_log2 is greater than the Scalar type number of bits
minus two.
The reason for this is that with a higher bound_log2 it is impossible to distinguish
between $-2^{bound_log2}$ and $2^{bound_log2}$ because of the 2’s complement
representation of integers.
pub const fn bound_log2(&self) -> u32
pub fn min_value_inclusive(&self) -> T::Signed
pub fn max_value_inclusive(&self) -> T::Signed
pub fn variance(&self, modulus: f64) -> Variance