pub struct CiphertextModulusLog(pub usize);Expand description
The number of bits used for the mask coefficients and the body of a ciphertext
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for CiphertextModulusLog
impl Clone for CiphertextModulusLog
Sourcefn clone(&self) -> CiphertextModulusLog
fn clone(&self) -> CiphertextModulusLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CiphertextModulusLog
Sourceimpl Debug for CiphertextModulusLog
impl Debug for CiphertextModulusLog
Sourceimpl<'de> Deserialize<'de> for CiphertextModulusLog
impl<'de> Deserialize<'de> for CiphertextModulusLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CiphertextModulusLog
Sourceimpl<Scalar: UnsignedInteger> From<CiphertextModulus<Scalar>> for CiphertextModulusLog
impl<Scalar: UnsignedInteger> From<CiphertextModulus<Scalar>> for CiphertextModulusLog
Sourcefn from(value: CiphertextModulus<Scalar>) -> Self
fn from(value: CiphertextModulus<Scalar>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CiphertextModulusLog
impl PartialEq for CiphertextModulusLog
Sourceimpl Serialize for CiphertextModulusLog
impl Serialize for CiphertextModulusLog
impl StructuralPartialEq for CiphertextModulusLog
Sourceimpl Unversionize for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl Unversionize for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl UnversionizeVec for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for CiphertextModulusLog
impl Version for CiphertextModulusLog
Sourceimpl Versionize for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl Versionize for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <CiphertextModulusLogVersions as VersionsDispatch<CiphertextModulusLog>>::Ref<'vers>
type Versioned<'vers> = <CiphertextModulusLogVersions as VersionsDispatch<CiphertextModulusLog>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl VersionizeOwned for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
type VersionedOwned = <CiphertextModulusLogVersions as VersionsDispatch<CiphertextModulusLog>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl VersionizeSlice for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<CiphertextModulusLog as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
impl VersionizeVec for CiphertextModulusLogwhere
CiphertextModulusLogVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<CiphertextModulusLog as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec