pub struct DecompositionBaseLog(pub usize);Expand description
The logarithm of the base used in a decomposition.
When decomposing an integer over powers of the $2^B$ basis, this type represents the $B$ value.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for DecompositionBaseLog
impl Clone for DecompositionBaseLog
Sourcefn clone(&self) -> DecompositionBaseLog
fn clone(&self) -> DecompositionBaseLog
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecompositionBaseLog
impl Debug for DecompositionBaseLog
Sourceimpl<'de> Deserialize<'de> for DecompositionBaseLog
impl<'de> Deserialize<'de> for DecompositionBaseLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DecompositionBaseLog
impl PartialEq for DecompositionBaseLog
Sourceimpl Serialize for DecompositionBaseLog
impl Serialize for DecompositionBaseLog
Sourceimpl Unversionize for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl Unversionize for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl UnversionizeVec for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for DecompositionBaseLog
impl Version for DecompositionBaseLog
Sourceimpl Versionize for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl Versionize for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <DecompositionBaseLogVersions as VersionsDispatch<DecompositionBaseLog>>::Ref<'vers>
type Versioned<'vers> = <DecompositionBaseLogVersions as VersionsDispatch<DecompositionBaseLog>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl VersionizeOwned for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
type VersionedOwned = <DecompositionBaseLogVersions as VersionsDispatch<DecompositionBaseLog>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl VersionizeSlice for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<DecompositionBaseLog as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
impl VersionizeVec for DecompositionBaseLogwhere
DecompositionBaseLogVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<DecompositionBaseLog as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<DecompositionBaseLog> for DecompositionBaseLogVersionswhere
DecompositionBaseLog: Version,
impl VersionsDispatch<DecompositionBaseLog> for DecompositionBaseLogVersionswhere
DecompositionBaseLog: Version,
impl Copy for DecompositionBaseLog
impl Eq for DecompositionBaseLog
impl StructuralPartialEq for DecompositionBaseLog