pub struct DecompositionLevelCount(pub usize);Expand description
The number of levels used in a decomposition.
When decomposing an integer over the $l$ largest powers of the basis, this type represents the $l$ value.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for DecompositionLevelCount
impl Clone for DecompositionLevelCount
Sourcefn clone(&self) -> DecompositionLevelCount
fn clone(&self) -> DecompositionLevelCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecompositionLevelCount
impl Debug for DecompositionLevelCount
Sourceimpl<'de> Deserialize<'de> for DecompositionLevelCount
impl<'de> Deserialize<'de> for DecompositionLevelCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DecompositionLevelCount
impl PartialEq for DecompositionLevelCount
Sourceimpl Serialize for DecompositionLevelCount
impl Serialize for DecompositionLevelCount
Sourceimpl Unversionize for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl Unversionize for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl UnversionizeVec for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for DecompositionLevelCount
impl Version for DecompositionLevelCount
Sourceimpl Versionize for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl Versionize for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <DecompositionLevelCountVersions as VersionsDispatch<DecompositionLevelCount>>::Ref<'vers>
type Versioned<'vers> = <DecompositionLevelCountVersions as VersionsDispatch<DecompositionLevelCount>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl VersionizeOwned for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
type VersionedOwned = <DecompositionLevelCountVersions as VersionsDispatch<DecompositionLevelCount>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl VersionizeSlice for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<DecompositionLevelCount as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
impl VersionizeVec for DecompositionLevelCountwhere
DecompositionLevelCountVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<DecompositionLevelCount as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<DecompositionLevelCount> for DecompositionLevelCountVersionswhere
DecompositionLevelCount: Version,
impl VersionsDispatch<DecompositionLevelCount> for DecompositionLevelCountVersionswhere
DecompositionLevelCount: Version,
impl Copy for DecompositionLevelCount
impl Eq for DecompositionLevelCount
impl StructuralPartialEq for DecompositionLevelCount