pub struct FunctionalPackingKeyswitchKeyCount(pub usize);Expand description
The number of functional packing keyswitch key in a functional packing keyswitch key list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for FunctionalPackingKeyswitchKeyCount
impl Clone for FunctionalPackingKeyswitchKeyCount
Sourcefn clone(&self) -> FunctionalPackingKeyswitchKeyCount
fn clone(&self) -> FunctionalPackingKeyswitchKeyCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FunctionalPackingKeyswitchKeyCount
impl<'de> Deserialize<'de> for FunctionalPackingKeyswitchKeyCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FunctionalPackingKeyswitchKeyCount
impl PartialEq for FunctionalPackingKeyswitchKeyCount
Sourcefn eq(&self, other: &FunctionalPackingKeyswitchKeyCount) -> bool
fn eq(&self, other: &FunctionalPackingKeyswitchKeyCount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Unversionize for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl Unversionize for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl UnversionizeVec for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Versionize for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl Versionize for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <FunctionalPackingKeyswitchKeyCountVersions as VersionsDispatch<FunctionalPackingKeyswitchKeyCount>>::Ref<'vers>
type Versioned<'vers> = <FunctionalPackingKeyswitchKeyCountVersions as VersionsDispatch<FunctionalPackingKeyswitchKeyCount>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl VersionizeOwned for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
type VersionedOwned = <FunctionalPackingKeyswitchKeyCountVersions as VersionsDispatch<FunctionalPackingKeyswitchKeyCount>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl VersionizeSlice for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<FunctionalPackingKeyswitchKeyCount as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
impl VersionizeVec for FunctionalPackingKeyswitchKeyCountwhere
FunctionalPackingKeyswitchKeyCountVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<FunctionalPackingKeyswitchKeyCount as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<FunctionalPackingKeyswitchKeyCount> for FunctionalPackingKeyswitchKeyCountVersions
impl VersionsDispatch<FunctionalPackingKeyswitchKeyCount> for FunctionalPackingKeyswitchKeyCountVersions
impl Copy for FunctionalPackingKeyswitchKeyCount
impl Eq for FunctionalPackingKeyswitchKeyCount
impl StructuralPartialEq for FunctionalPackingKeyswitchKeyCount