pub struct GgswCiphertextCount(pub usize);Expand description
The number of ciphertexts in a ggsw ciphertext list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for GgswCiphertextCount
impl Clone for GgswCiphertextCount
Sourcefn clone(&self) -> GgswCiphertextCount
fn clone(&self) -> GgswCiphertextCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GgswCiphertextCount
impl Debug for GgswCiphertextCount
Sourceimpl<'de> Deserialize<'de> for GgswCiphertextCount
impl<'de> Deserialize<'de> for GgswCiphertextCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GgswCiphertextCount
impl PartialEq for GgswCiphertextCount
Sourceimpl Serialize for GgswCiphertextCount
impl Serialize for GgswCiphertextCount
Sourceimpl Unversionize for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl Unversionize for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl UnversionizeVec for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for GgswCiphertextCount
impl Version for GgswCiphertextCount
Sourceimpl Versionize for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl Versionize for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <GgswCiphertextCountVersions as VersionsDispatch<GgswCiphertextCount>>::Ref<'vers>
type Versioned<'vers> = <GgswCiphertextCountVersions as VersionsDispatch<GgswCiphertextCount>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeOwned for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedOwned = <GgswCiphertextCountVersions as VersionsDispatch<GgswCiphertextCount>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeSlice for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<GgswCiphertextCount as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeVec for GgswCiphertextCountwhere
GgswCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<GgswCiphertextCount as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<GgswCiphertextCount> for GgswCiphertextCountVersionswhere
GgswCiphertextCount: Version,
impl VersionsDispatch<GgswCiphertextCount> for GgswCiphertextCountVersionswhere
GgswCiphertextCount: Version,
impl Copy for GgswCiphertextCount
impl Eq for GgswCiphertextCount
impl StructuralPartialEq for GgswCiphertextCount