pub struct LweCiphertextCount(pub usize);Expand description
The number of ciphertexts in an lwe ciphertext list.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for LweCiphertextCount
impl Clone for LweCiphertextCount
Sourcefn clone(&self) -> LweCiphertextCount
fn clone(&self) -> LweCiphertextCount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LweCiphertextCount
impl Debug for LweCiphertextCount
Sourceimpl<'de> Deserialize<'de> for LweCiphertextCount
impl<'de> Deserialize<'de> for LweCiphertextCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for LweCiphertextCount
impl Ord for LweCiphertextCount
Sourcefn cmp(&self, other: &LweCiphertextCount) -> Ordering
fn cmp(&self, other: &LweCiphertextCount) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LweCiphertextCount
impl PartialEq for LweCiphertextCount
Sourceimpl PartialOrd for LweCiphertextCount
impl PartialOrd for LweCiphertextCount
Sourceimpl Serialize for LweCiphertextCount
impl Serialize for LweCiphertextCount
Sourceimpl Unversionize for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl Unversionize for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl UnversionizeVec for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for LweCiphertextCount
impl Version for LweCiphertextCount
Sourceimpl Versionize for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl Versionize for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <LweCiphertextCountVersions as VersionsDispatch<LweCiphertextCount>>::Ref<'vers>
type Versioned<'vers> = <LweCiphertextCountVersions as VersionsDispatch<LweCiphertextCount>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeOwned for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedOwned = <LweCiphertextCountVersions as VersionsDispatch<LweCiphertextCount>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeSlice for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<LweCiphertextCount as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
impl VersionizeVec for LweCiphertextCountwhere
LweCiphertextCountVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<LweCiphertextCount as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<LweCiphertextCount> for LweCiphertextCountVersionswhere
LweCiphertextCount: Version,
impl VersionsDispatch<LweCiphertextCount> for LweCiphertextCountVersionswhere
LweCiphertextCount: Version,
impl Copy for LweCiphertextCount
impl Eq for LweCiphertextCount
impl StructuralPartialEq for LweCiphertextCount