pub struct ModulusSwitchOffset(pub usize);Expand description
The number of MSB shifted in a Modulus Switch.
When performing a Modulus Switch, this type represents the number of MSB that will be discarded.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for ModulusSwitchOffset
impl Clone for ModulusSwitchOffset
Sourcefn clone(&self) -> ModulusSwitchOffset
fn clone(&self) -> ModulusSwitchOffset
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ModulusSwitchOffset
Sourceimpl Debug for ModulusSwitchOffset
impl Debug for ModulusSwitchOffset
Sourceimpl<'de> Deserialize<'de> for ModulusSwitchOffset
impl<'de> Deserialize<'de> for ModulusSwitchOffset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModulusSwitchOffset
Sourceimpl PartialEq for ModulusSwitchOffset
impl PartialEq for ModulusSwitchOffset
Sourceimpl Serialize for ModulusSwitchOffset
impl Serialize for ModulusSwitchOffset
impl StructuralPartialEq for ModulusSwitchOffset
Sourceimpl Unversionize for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl Unversionize for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl UnversionizeVec for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Version for ModulusSwitchOffset
impl Version for ModulusSwitchOffset
Sourceimpl Versionize for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl Versionize for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <ModulusSwitchOffsetVersions as VersionsDispatch<ModulusSwitchOffset>>::Ref<'vers>
type Versioned<'vers> = <ModulusSwitchOffsetVersions as VersionsDispatch<ModulusSwitchOffset>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl VersionizeOwned for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
type VersionedOwned = <ModulusSwitchOffsetVersions as VersionsDispatch<ModulusSwitchOffset>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl VersionizeSlice for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<ModulusSwitchOffset as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
impl VersionizeVec for ModulusSwitchOffsetwhere
ModulusSwitchOffsetVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<ModulusSwitchOffset as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec