StaticSignedBigInt

Struct StaticSignedBigInt 

pub struct StaticSignedBigInt<const N: usize>(/* private fields */);

Implementations

Source

impl<const N: usize> StaticSignedBigInt<N>

pub const BITS: u32

pub const MAX: Self

pub const MIN: Self

pub const ZERO: Self

pub const ONE: Self

pub const TWO: Self

pub fn data(&self) -> &[u64; N]

pub fn wrapping_neg(self) -> Self

pub fn wrapping_sub(self, other: Self) -> Self

pub fn copy_from_be_byte_slice(&mut self, bytes: &[u8])

Replaces the current value by interpreting the bytes in big endian order

pub fn copy_from_le_byte_slice(&mut self, bytes: &[u8])

Replaces the current value by interpreting the bytes in little endian order

pub fn copy_to_le_byte_slice(&self, bytes: &mut [u8])

pub fn copy_to_be_byte_slice(&self, bytes: &mut [u8])

pub fn is_power_of_two(self) -> bool

pub fn leading_zeros(self) -> u32

pub fn ilog2(self) -> u32

pub fn ceil_ilog2(self) -> u32

pub fn wrapping_abs(self) -> Self