pub struct ReRandomizationSeedGen { /* private fields */ }Expand description
A generator that can be used to obtain seeds needed to re-randomize individual ciphertexts.
This will refuse to generate more seeds than the number of ciphertext added into the context.
Implementations
Sourceimpl ReRandomizationSeedGen
impl ReRandomizationSeedGen
Sourcepub fn next_seed(&mut self) -> Result<ReRandomizationSeed>
pub fn next_seed(&mut self) -> Result<ReRandomizationSeed>
Generate the next seed from the seeder.
Returns an error if more seeds have been generated than the number of ciphertext added into the context.