Module client_key

Module client_key 

This module implements the generation of the client keys structs

Client keys are the keys used to encrypt an decrypt data. These are private and MUST NOT be shared.

Structs

ClientKey
A structure containing the client key, which must be kept secret.
CrtClientKey
Client key “specialized” for CRT decomposition.
RadixClientKey
Client key “specialized” for radix decomposition.