pub enum IntegerKeyKind {
Radix,
CRT,
}Expand description
Enum to indicate which kind of computations the ServerKey will be performing, this changes
the parameterization of the key to manage carries in the Radix case.
Variants