CompressedKVStore

Struct CompressedKVStore 

pub struct CompressedKVStore<Key, Value> { /* private fields */ }
Compressed KVStore

This type is the serializable and deserializable form of a KVStore

Implementations

Source

impl<Key, Value> CompressedKVStore<Key, Value>

pub fn decompress( &self, decompression_key: &DecompressionKey, ) -> Result<KVStore<Key, Value>>
where Key: Copy + Display + Ord,

Decompressed the KVStore

Returns an error if:

  • The requested value type does not have the same signedness as the stored one
  • A key does not have a corresponding value
  • A value (which is a radix ciphertext) does not have the same number of blocks as the others.

Both these errors indicate corrupted or malformed data