KVStore

Struct KVStore 

pub struct KVStore<Key, Ct> { /* private fields */ }
The KVStore is a specialized encrypted HashMap

  • Keys are clear numbers
  • Values are RadixCiphertext or SignedRadixCiphertext

It supports getting/modifying existing pairs of (key,value) using an encrypted key.

To serialize a KVStore it must first be compressed with KVStore::compress

Implementations

Source

impl<Key, Ct> KVStore<Key, Ct>

pub fn new() -> Self

Creates an empty KVStore

pub fn get(&self, key: &Key) -> Option<&Ct>
where Key: Ord,

Returns the value stored for the key if any

Key is in clear, see ServerKey::kv_store_get if you wish to query using an encrypted key

pub fn get_mut(&mut self, key: &Key) -> Option<&mut Ct>
where Key: Ord,

Returns the value stored for the key if any

Key is in clear, see ServerKey::kv_store_get if you wish to query using an encrypted key

pub fn insert(&mut self, key: Key, value: Ct) -> Option<Ct>
where Key: Ord, Ct: IntegerRadixCiphertext,

Inserts the value for the key

Returns the previous value stored for the key if there was any

Notes

If the value does not contain blocks, nothing is inserted and None is returned

Panics

Panics if the number of blocks of the value is not the same as all other values stored

pub fn remove(&mut self, key: &Key) -> Option<Ct>
where Key: Ord,

Removes a key-value pair.

pub fn clear_get(&self, key: &Key) -> Option<&Ct>
where Key: Ord,

Returns the value associated to the key given in clear

pub fn contains_key(&self, key: &Key) -> bool
where Key: Ord,

pub fn len(&self) -> usize

Returns the number of key-value pairs currently stored

pub fn is_empty(&self) -> bool

Returns whether the store is empty

pub fn iter(&self) -> impl Iterator<Item = (&Key, &Ct)>
where Key: Ord, Ct: Send,

Source

impl<Key, Ct> KVStore<Key, Ct>

pub fn compress( &self, compression_key: &CompressionKey, ) -> CompressedKVStore<Key, Ct>

Compress the KVStore to be able to serialize it