DeserializationConfig

Struct DeserializationConfig 

pub struct DeserializationConfig { /* private fields */ }
A configuration used to Serialize TFHE-rs objects. This configuration decides the various sanity checks that will be performed during deserialization.

Implementations

Source

impl DeserializationConfig

pub fn new(deserialized_size_limit: u64) -> Self

Creates a new deserialization config.

By default, it will check that the serialization version and the name of the deserialized type are correct. deserialized_size_limit is the size limit (in number of bytes) of the deserialized object. It should be set according to the expected size of the object and the maximum allocatable size on your system.

It will also check that the object is conformant with the parameter set given in conformance_params. Finally, it will check the compatibility of the loaded data with the current TFHE-rs version.

pub fn new_with_unlimited_size() -> Self

Creates a new config without any size limit for the deserialized objects.

pub fn disable_size_limit(self) -> Self

Disables the size limit for the serialized objects.

pub fn with_size_limit(self, size: u64) -> Self

Sets the size limit for this deserialization config

pub fn disable_header_validation(self) -> Self

Disables the header validation on the object. This header validations checks that the serialized object is the one that is supposed to be loaded and is compatible with this version of TFHE-rs.

pub fn disable_conformance(self) -> NonConformantDeserializationConfig

Disables the conformance check on an existing config.

pub fn deserialize_from<T: DeserializeOwned + Unversionize + Named + ParameterSetConformant>( self, reader: impl Read, parameter_set: &T::ParameterSet, ) -> Result<T, String>

Deserializes an object serialized by SerializationConfig::serialize_into from a reader. Performs various sanity checks based on the deserialization config.

Panics

This function may panic if serialized_size_limit is larger than what can be allocated by the system. This may happen even if the size of the serialized data is short. An attacker could manipulate the data to create a short serialized message with a huge deserialized size.