CompactPublicKeyEncryptionParameters

Struct CompactPublicKeyEncryptionParameters 

pub struct CompactPublicKeyEncryptionParameters {
    pub encryption_lwe_dimension: LweDimension,
    pub encryption_noise_distribution: DynamicDistribution<u64>,
    pub message_modulus: MessageModulus,
    pub carry_modulus: CarryModulus,
    pub ciphertext_modulus: CiphertextModulus,
    pub expansion_kind: CompactCiphertextListExpansionKind,
    pub zk_scheme: SupportedCompactPkeZkScheme,
}

Fields

encryption_lwe_dimension: LweDimensionencryption_noise_distribution: DynamicDistribution<u64>message_modulus: MessageModuluscarry_modulus: CarryModulusciphertext_modulus: CiphertextModulusexpansion_kind: CompactCiphertextListExpansionKindzk_scheme: SupportedCompactPkeZkScheme

Implementations

Source

impl CompactPublicKeyEncryptionParameters

pub const fn try_new( encryption_lwe_dimension: LweDimension, encryption_noise_distribution: DynamicDistribution<u64>, message_modulus: MessageModulus, carry_modulus: CarryModulus, ciphertext_modulus: CiphertextModulus, output_ciphertext_kind: CompactCiphertextListExpansionKind, zk_scheme: SupportedCompactPkeZkScheme, ) -> Result<Self, &'static str>

pub const fn is_valid(&self) -> bool

pub const fn validate(self) -> Self

This should be used while defining static parameters to verify they comply with the requirements of compact public key encryption.

pub const fn from_shortint_parameter_set( parameters: ShortintParameterSet, ) -> Result<Self, &'static str>