pub struct ModulusSwitchNoiseReductionParams {
pub modulus_switch_zeros_count: LweCiphertextCount,
pub ms_bound: NoiseEstimationMeasureBound,
pub ms_r_sigma_factor: RSigmaFactor,
pub ms_input_variance: Variance,
}Fields
modulus_switch_zeros_count: LweCiphertextCountms_bound: NoiseEstimationMeasureBoundms_r_sigma_factor: RSigmaFactorms_input_variance: VarianceTrait Implementations
Sourceimpl Clone for ModulusSwitchNoiseReductionParams
impl Clone for ModulusSwitchNoiseReductionParams
Sourcefn clone(&self) -> ModulusSwitchNoiseReductionParams
fn clone(&self) -> ModulusSwitchNoiseReductionParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ModulusSwitchNoiseReductionParams
impl<'de> Deserialize<'de> for ModulusSwitchNoiseReductionParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ModulusSwitchNoiseReductionParams
impl PartialEq for ModulusSwitchNoiseReductionParams
Sourcefn eq(&self, other: &ModulusSwitchNoiseReductionParams) -> bool
fn eq(&self, other: &ModulusSwitchNoiseReductionParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Unversionize for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl Unversionize for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
Sourcefn unversionize(
versioned: Self::VersionedOwned,
) -> Result<Self, UnversionizeError>
fn unversionize( versioned: Self::VersionedOwned, ) -> Result<Self, UnversionizeError>
Creates an object from a versioned enum, and eventually upgrades from previous
variants.
Sourceimpl UnversionizeVec for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl UnversionizeVec for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
fn unversionize_vec( versioned: Self::VersionedVec, ) -> Result<Vec<Self>, UnversionizeError>
Sourceimpl Versionize for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl Versionize for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
Sourcetype Versioned<'vers> = <ModulusSwitchNoiseReductionParamsVersions as VersionsDispatch<ModulusSwitchNoiseReductionParams>>::Ref<'vers>
type Versioned<'vers> = <ModulusSwitchNoiseReductionParamsVersions as VersionsDispatch<ModulusSwitchNoiseReductionParams>>::Ref<'vers>
The equivalent versioned type. It should have a variant for each version.
It may own the underlying data or only hold a read-only reference to it.
Sourcefn versionize(&self) -> Self::Versioned<'_>
fn versionize(&self) -> Self::Versioned<'_>
Wraps the object into a versioned enum with a variant for each version. This will
use references on the underlying types if possible.
Sourceimpl VersionizeOwned for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl VersionizeOwned for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
type VersionedOwned = <ModulusSwitchNoiseReductionParamsVersions as VersionsDispatch<ModulusSwitchNoiseReductionParams>>::Owned
Sourcefn versionize_owned(self) -> Self::VersionedOwned
fn versionize_owned(self) -> Self::VersionedOwned
Wraps the object into a versioned enum with a variant for each version. This will
clone the underlying types.
Sourceimpl VersionizeSlice for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl VersionizeSlice for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
type VersionedSlice<'vers> = Vec<<ModulusSwitchNoiseReductionParams as Versionize>::Versioned<'vers>>
fn versionize_slice(slice: &[Self]) -> Self::VersionedSlice<'_>
Sourceimpl VersionizeVec for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
impl VersionizeVec for ModulusSwitchNoiseReductionParamswhere
ModulusSwitchNoiseReductionParamsVersions: VersionsDispatch<Self>,
type VersionedVec = Vec<<ModulusSwitchNoiseReductionParams as VersionizeOwned>::VersionedOwned>
fn versionize_vec(vec: Vec<Self>) -> Self::VersionedVec
Sourceimpl VersionsDispatch<ModulusSwitchNoiseReductionParams> for ModulusSwitchNoiseReductionParamsVersions
impl VersionsDispatch<ModulusSwitchNoiseReductionParams> for ModulusSwitchNoiseReductionParamsVersions
impl Copy for ModulusSwitchNoiseReductionParams
impl StructuralPartialEq for ModulusSwitchNoiseReductionParams