ClientKey

Struct ClientKey 

pub struct ClientKey<T>
where T: Borrow<ClientKey>,
{ /* private fields */ }

Implementations

Source

impl<T> ClientKey<T>
where T: Borrow<ClientKey>,

pub fn new(inner: T) -> Self

pub fn inner(&self) -> &IntegerClientKey

Source

impl<T> ClientKey<T>
where T: Borrow<ClientKey>,

pub fn encrypt_ascii(&self, str: &str, padding: Option<u32>) -> FheString

Encrypts an ASCII string, optionally padding it with the specified amount of 0s, and returns an FheString.

Panics

This function will panic if the provided string is not ASCII or contains null characters “\0”.

pub fn decrypt_ascii(&self, enc_str: &FheString) -> String

Decrypts a FheString, removes any padding and returns the ASCII string.

Panics

This function will panic if the decrypted string is not ASCII or the FheString padding flag doesn’t match the actual string.

pub fn encrypt_u16(&self, val: u16, max: Option<u16>) -> EncU16

Encrypts a u16 value. It also takes an optional max value to restrict the range of the encrypted u16.

Panics

This function will panic if the u16 value exceeds the provided max.