Struct tfhe::ClientKey

source ·
pub struct ClientKey { /* private fields */ }
Available on crate features boolean or shortint or integer only.
Key of the client

This struct contains the keys that are of interest to the user as they will allow to encrypt and decrypt data.

This key MUST NOT be sent to the server.

Implementations

source

impl ClientKey

source

pub fn generate<C: Into<Config>>(config: C) -> ClientKey

Generates a new keys.

source

pub fn generate_with_seed<C: Into<Config>>(config: C, seed: Seed) -> ClientKey

source

pub fn generate_server_key(&self) -> ServerKey

Generates a new ServerKey

The ServerKey generated is meant to be used to initialize the global state using crate::high_level_api::set_server_key.

source

pub fn generate_compressed_server_key(&self) -> CompressedServerKey

Generates a new CompressedServerKey