CompactCiphertextListBuilder

Struct CompactCiphertextListBuilder 

pub struct CompactCiphertextListBuilder { /* private fields */ }

Implementations

Source

impl CompactCiphertextListBuilder

pub fn new(pk: &CompactPublicKey) -> Self

pub fn push<T>(&mut self, value: T) -> &mut Self
where T: HlCompactable,

pub fn extend<T>(&mut self, values: impl Iterator<Item = T>) -> &mut Self
where T: HlCompactable,

pub fn push_with_num_bits<T>( &mut self, number: T, num_bits: usize, ) -> Result<&mut Self>

pub fn extend_with_num_bits<T>( &mut self, values: impl Iterator<Item = T>, num_bits: usize, ) -> Result<&mut Self>

pub fn build(&self) -> CompactCiphertextList

pub fn build_packed(&self) -> CompactCiphertextList

pub fn build_packed_seeded(&self, seed: &[u8]) -> Result<CompactCiphertextList>

Builds the list using the given seed, useful to have determinism for encryption

Warning

The seed must be kept secure, if attackers gets the seed they can break the encryption

pub fn build_with_proof_packed( &self, crs: &CompactPkeCrs, metadata: &[u8], compute_load: ZkComputeLoad, ) -> Result<ProvenCompactCiphertextList>

pub fn build_with_proof_packed_seeded( &self, crs: &CompactPkeCrs, metadata: &[u8], compute_load: ZkComputeLoad, seed: &[u8], ) -> Result<ProvenCompactCiphertextList>

Builds a proved list using the given seed, useful to have determinism for encryption

Warning

The seed must be kept secure, if attackers gets the seed they can break the encryption

Source

impl CompactCiphertextListBuilder

pub fn push_string(&mut self, string: &ClearString) -> &mut Self

pub fn push_string_with_padding( &mut self, clear_string: &ClearString, padding_count: u32, ) -> &mut Self

pub fn push_string_with_fixed_size( &mut self, clear_string: &ClearString, size: u32, ) -> &mut Self