Struct tfhe::CompactFheBoolList
source · pub struct CompactFheBoolList { /* private fields */ }Available on crate feature
integer only.Expand description
Compact list of FheBool
Meant to save in storage space / transfer.
- A Compact type must be expanded using expand before it can be used.
- It is not possible to ‘compact’ an existing FheBool. Compacting can only be achieved at encryption time by a CompactPublicKey
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, CompactFheBoolList, CompactPublicKey, ConfigBuilder};
let (client_key, _) = generate_keys(ConfigBuilder::default());
let compact_public_key = CompactPublicKey::try_new(&client_key).unwrap();
let clears = vec![false, true];
let compact = CompactFheBoolList::encrypt(&clears, &compact_public_key);
assert_eq!(compact.len(), clears.len());
let ciphertexts = compact.expand();
let decrypted: Vec<bool> = ciphertexts
.into_iter()
.map(|ciphertext| ciphertext.decrypt(&client_key))
.collect();
assert_eq!(decrypted, clears);Implementations