Struct tfhe::ConfigBuilder

source ·
pub struct ConfigBuilder { /* private fields */ }
Available on crate features boolean or shortint or integer only.
The builder to create your config

This struct is what you will to use to build your configuration.

Why ?

The configuration is needed to select which types you are going to use or not and which parameters you wish to use for these types (whether it is the default parameters or some custom parameters).

To be able to configure a type, its “cargo feature kind” must be enabled (see the table).

The configuration is needed for the crate to be able to initialize and generate all the needed client and server keys as well as other internal details.

As generating these keys and details for types that you are not going to use would be a waste of time and space (both memory and disk if you serialize), generating a config is an important step.

Implementations

source

impl ConfigBuilder

source

pub fn all_enabled() -> Self

Create a new builder with all the data types activated with their default parameters

source

pub fn all_disabled() -> Self

Create a new builder with all the data types disabled

source

pub fn enable_default_bool(self) -> Self

Available on crate feature boolean only.
source

pub fn enable_custom_bool(self, params: FheBoolParameters) -> Self

Available on crate feature boolean only.
source

pub fn disable_bool(self) -> Self

Available on crate feature boolean only.
source

pub fn enable_default_uint2(self) -> Self

Available on crate feature shortint only.
source

pub fn enable_default_uint3(self) -> Self

Available on crate feature shortint only.
source

pub fn enable_default_uint4(self) -> Self

Available on crate feature shortint only.
source

pub fn enable_default_integers(self) -> Self

Available on crate feature integer only.
source

pub fn enable_default_integers_small(self) -> Self

Available on crate feature integer only.
source

pub fn enable_custom_integers<P>( self, block_parameters: P, wopbs_block_parameters: Option<WopbsParameters> ) -> Selfwhere P: Into<PBSParameters>,

Available on crate feature integer only.
source

pub fn disable_integers(self) -> Self

Available on crate feature integer only.
source

pub fn build(self) -> Config