KVStore

Struct KVStore 

pub struct KVStore<Key, T>
where T: FheIntegerType,
{ /* private fields */ }
The KVStore is a specialized encrypted HashMap

  • Keys are clear numbers
  • Values are FheInt or FheUint

This store allows inserting, removing, and getting values using clear keys. It also allows to do some operations using encrypted keys.

To serialize a KVStore it must first be compressed with KVStore::compress

Tag System

Ciphertexts inserted into the KVStore will drop their tag. Operations on the KVStore that return a ciphertext will set a tag using the currently set server key. Even operations that do not require FHE operations will require a server key to be set in order to set the tag

Implementations

Source

impl<Key, T> KVStore<Key, T>
where T: FheIntegerType,

pub fn new() -> Self

Creates a new empty KVStore.

Defaults to the CPU variant when no server key is set.

pub fn len(&self) -> usize

Returns the number of key-value pairs in the store.

pub fn is_empty(&self) -> bool

Returns true if the store contains no key-value pairs

pub fn insert_with_clear_key(&mut self, key: Key, value: T) -> Option<T>
where Key: Ord,

Inserts a key-value pair.

Returns the old value if there was any

pub fn update_with_clear_key(&mut self, key: &Key, value: T) -> Option<T>
where Key: Ord,

Updates the value in a key-value pair.

Returns the old value if there was any Returns None if the key had no previous value

If your key is encrypted see Self::update

Note

Contraty to Self::insert_with_clear_key, this does not insert the key,value pair if its not present

pub fn remove_with_clear_key(&mut self, key: &Key) -> Option<T>
where Key: Ord,

Removes a key-value pair.

Returns Some(_) if the key was present, None otherwise

Note

Even though no FHE computations are done, a server key must be set when calling this function is order to set the Tag of the resulting ciphertext

pub fn contains_clear_key(&self, key: &Key) -> bool
where Key: Ord,

Returns true if the store contains a value for the given clear key.

If your key is encrypted see Self::contains_key

pub fn get_with_clear_key(&self, key: &Key) -> Option<T>
where Key: Ord,

Returns the value associated to a key.

Returns Some(_) if the key was present, None otherwise

If your key is encrypted see Self::get

Note

Even though no FHE computations are done, a server key must be set when calling this function is order to set the Tag of the resulting ciphertext

Source

impl<Key, T> KVStore<Key, T>

pub fn get<EK>(&self, encrypted_key: &EK) -> (T, FheBool)
where EK: FheIntegerType, EK::Id: IntegerId<InnerCpu = <T::Id as IntegerId>::InnerCpu, InnerGpu = <T::Id as IntegerId>::InnerGpu>,

Gets the value corresponding to the encrypted key.

Returns the encrypted value and an encrypted boolean. The boolean is an encryption of true if the key was present, thus the value is meaningful.

If your key is clear see Self::get_with_clear_key

pub fn contains_key<EK>(&self, encrypted_key: &EK) -> FheBool
where EK: FheIntegerType, EK::Id: IntegerId<InnerCpu = <T::Id as IntegerId>::InnerCpu, InnerGpu = <T::Id as IntegerId>::InnerGpu>,

Checks if the store contains a value for the given encrypted key.

Returns an encrypted boolean that encrypts true if the key was found.

If your key is clear see Self::contains_clear_key

pub fn contains_value(&self, encrypted_value: &T) -> FheBool

Checks if the store contains the given encrypted value.

Returns an encrypted boolean that encrypts true if the value was found.

pub fn contains_clear_value<Clear>(&self, clear_value: Clear) -> FheBool
where Clear: DecomposableInto<u64>,

Checks if the store contains the given clear value.

Returns an encrypted boolean that encrypts true if the value was found.

pub fn update<EK>(&mut self, encrypted_key: &EK, new_value: &T) -> FheBool
where EK: FheIntegerType, EK::Id: IntegerId<InnerCpu = <T::Id as IntegerId>::InnerCpu, InnerGpu = <T::Id as IntegerId>::InnerGpu>,

Replaces the value corresponding to the encrypted key.

i.e. kvstore[encrypted_value] = new_value

The boolean is an encryption of true if the key was present, thus the value is was replaced.

If your key is clear see Self::update_with_clear_key

pub fn map<EK, F>(&mut self, encrypted_key: &EK, func: F) -> (T, T, FheBool)
where EK: FheIntegerType, EK::Id: IntegerId<InnerCpu = <T::Id as IntegerId>::InnerCpu, InnerGpu = <T::Id as IntegerId>::InnerGpu>, F: Fn(T) -> T,

Replaces the value corresponding to the encrypted key, with the result of applying the function to the current value.

i.e. kvstore[encrypted_value] = func(kvstore[encrypted_value])

Returns (old_value, new_value, check)

The check boolean is an encryption of true if the key was present, thus the value is was replaced.

pub fn compress(&self) -> Result<CompressedKVStore<Key, T>>
where Key: Copy + Display + Ord, <T::Id as IntegerId>::InnerCpu: Compressible + Clone,

Compressed the KVStore, making it serializable