pub struct BooleanKeySwitchingParameters {
pub ks_base_log: DecompositionBaseLog,
pub ks_level: DecompositionLevelCount,
}Expand description
A set of cryptographic parameters for homomorphic Boolean key switching.
Fields
ks_base_log: DecompositionBaseLogks_level: DecompositionLevelCountImplementations
Sourceimpl BooleanKeySwitchingParameters
impl BooleanKeySwitchingParameters
Sourcepub fn new(
ks_base_log: DecompositionBaseLog,
ks_level: DecompositionLevelCount,
) -> Self
pub fn new( ks_base_log: DecompositionBaseLog, ks_level: DecompositionLevelCount, ) -> Self
Constructs a new set of parameters for boolean circuit evaluation.
Warning
Failing to fix the parameters properly would yield incorrect and insecure computation. Unless you are a cryptographer who really knows the impact of each of those parameters, you must stick with the provided parameters (if any), which both offer correct results with 128 bits of security.