pub struct StaticUnsignedBigInt<const N: usize>(/* private fields */);Implementations
Sourceimpl<const N: usize> StaticUnsignedBigInt<N>
impl<const N: usize> StaticUnsignedBigInt<N>
pub const BITS: u32
pub const MAX: Self
pub const MIN: Self
pub const ZERO: Self
pub const ONE: Self
pub const TWO: Self
Sourcepub fn copy_from_be_byte_slice(&mut self, bytes: &[u8])
pub fn copy_from_be_byte_slice(&mut self, bytes: &[u8])
Replaces the current value by interpreting the bytes in big endian order
Sourcepub fn copy_from_le_byte_slice(&mut self, bytes: &[u8])
pub fn copy_from_le_byte_slice(&mut self, bytes: &[u8])
Replaces the current value by interpreting the bytes in little endian order
pub fn copy_to_le_byte_slice(&self, bytes: &mut [u8])
pub fn copy_to_be_byte_slice(&self, bytes: &mut [u8])
pub fn is_power_of_two(self) -> bool
pub fn leading_zeros(self) -> u32
pub fn ilog2(self) -> u32
pub fn ceil_ilog2(self) -> u32
pub fn wrapping_sub(self, other: Self) -> Self
Sourceimpl StaticUnsignedBigInt<4>
impl StaticUnsignedBigInt<4>
pub fn to_low_high_u128(self) -> (u128, u128)