pub struct CompactCiphertextList { /* private fields */ }Implementations
Sourceimpl CompactCiphertextList
impl CompactCiphertextList
pub fn is_packed(&self) -> bool
pub fn needs_casting(&self) -> bool
pub fn builder(pk: &CompactPublicKey) -> CompactCiphertextListBuilder
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn get_kind_of(&self, index: usize) -> Option<DataKind>
Sourcepub fn into_raw_parts(self) -> (CompactCiphertextList, Vec<DataKind>)
pub fn into_raw_parts(self) -> (CompactCiphertextList, Vec<DataKind>)
Deconstruct a CompactCiphertextList into its constituents.
Sourcepub fn from_raw_parts(
ct_list: CompactCiphertextList,
info: Vec<DataKind>,
) -> Self
pub fn from_raw_parts( ct_list: CompactCiphertextList, info: Vec<DataKind>, ) -> Self
Construct a CompactCiphertextList from its constituents.
Panics
Panics if the constituents are not compatible with each others.
Sourcepub fn reinterpret_data(&mut self, info: &[DataKind]) -> Result<(), Error>
pub fn reinterpret_data(&mut self, info: &[DataKind]) -> Result<(), Error>
Allows to change the info about the data kind store in the CompactCiphertextList.
This can be useful if you are loading an old version of the CompactCiphertextList which
did not store the metadata before.
The user is responsible of ensuring data consistency as the library cannot do that automatically. This can be a problem for boolean data if a block does not encrypt a 0 or a 1.
use tfhe::integer::ciphertext::{
CompactCiphertextList, DataKind, IntegerCompactCiphertextListExpansionMode,
RadixCiphertext, SignedRadixCiphertext,
};
use tfhe::integer::{ClientKey, CompactPublicKey};
use tfhe::shortint::parameters::PARAM_MESSAGE_2_CARRY_2_KS_PBS_GAUSSIAN_2M128;
let fhe_params = PARAM_MESSAGE_2_CARRY_2_KS_PBS_GAUSSIAN_2M128;
let num_blocks = 4usize;
let cks = ClientKey::new(fhe_params);
let pk = CompactPublicKey::new(&cks);
let mut compact_ct = CompactCiphertextList::builder(&pk).push(-1i8).build();
let sanity_check_expander = compact_ct
.expand(IntegerCompactCiphertextListExpansionMode::NoCastingAndNoUnpacking)
.unwrap();
let sanity_expanded = sanity_check_expander
.get::<SignedRadixCiphertext>(0)
.unwrap()
.unwrap();
let sanity_decrypted: i8 = cks.decrypt_signed_radix(&sanity_expanded);
assert_eq!(-1i8, sanity_decrypted);
compact_ct
.reinterpret_data(&[DataKind::Unsigned(num_blocks.try_into().unwrap())])
.unwrap();
let expander = compact_ct
.expand(IntegerCompactCiphertextListExpansionMode::NoCastingAndNoUnpacking)
.unwrap();
let expanded = expander.get::<RadixCiphertext>(0).unwrap().unwrap();
let decrypted: u8 = cks.decrypt_radix(&expanded);
// -1i8 == u8::MAX
assert_eq!(u8::MAX, decrypted);pub fn ciphertext_count(&self) -> usize
pub fn expand( &self, expansion_mode: IntegerCompactCiphertextListExpansionMode<'_>, ) -> Result<CompactCiphertextListExpander>
pub fn size_elements(&self) -> usize
pub fn size_bytes(&self) -> usize
pub fn message_modulus(&self) -> MessageModulus