pub struct ReRandomizationContext { /* private fields */ }Expand description
The context that will be hashed and used to generate unique ReRandomizationSeed.
Implementations
Sourceimpl ReRandomizationContext
impl ReRandomizationContext
Sourcepub fn new<'a>(
rerand_seeder_domain_separator: [u8; 8],
fn_description: impl IntoIterator<Item = &'a [u8]>,
public_encryption_domain_separator: [u8; 8],
) -> Self
pub fn new<'a>( rerand_seeder_domain_separator: [u8; 8], fn_description: impl IntoIterator<Item = &'a [u8]>, public_encryption_domain_separator: [u8; 8], ) -> Self
Create a new re-randomization context with the default seed hasher (blake3).
rerand_seeder_domain_separator is the domain separator that will be fed into the
seed generator.
public_encryption_domain_separator is the domain separator that will be used along this
seed to generate the encryptions of zero.
fn_description is a unique sequence of bytes that represents the functions called on the
re-randomized values.
(See XofSeed for more information)
Example
use tfhe::integer::ciphertext::ReRandomizationContext;
// Simulate a 256 bits nonce
let nonce: [u8; 256 / 8] = core::array::from_fn(|_| rand::random());
let _re_rand_context = ReRandomizationContext::new(
*b"TFHE_Rrd",
[b"FheUint64+FheUint64".as_slice(), &nonce],
*b"TFHE_Enc"
);Sourcepub fn new_with_hasher<'a>(
fn_description: impl IntoIterator<Item = &'a [u8]>,
public_encryption_domain_separator: [u8; 8],
seed_hasher: ReRandomizationSeedHasher,
) -> Self
pub fn new_with_hasher<'a>( fn_description: impl IntoIterator<Item = &'a [u8]>, public_encryption_domain_separator: [u8; 8], seed_hasher: ReRandomizationSeedHasher, ) -> Self
Create a new re-randomization context with the provided seed hasher.
Sourcepub fn add_ciphertext<T: AsShortintCiphertextSlice>(&mut self, ciphertext: &T)
pub fn add_ciphertext<T: AsShortintCiphertextSlice>(&mut self, ciphertext: &T)
Add a new integer ciphertext to the context.
The ciphertexts added like this will be stored in a temporary buffer and only hashed during the “finalize” step
pub fn add_proven_ciphertext_list(&mut self, list: &ProvenCompactCiphertextList)
Sourcepub fn add_bytes(&mut self, data: &[u8])
pub fn add_bytes(&mut self, data: &[u8])
Add a metadata buffer to the context.
These bytes will be added to a temporary buffer and will only be hashed during the “finalize” step
Sourcepub fn finalize(self) -> ReRandomizationSeedGen
pub fn finalize(self) -> ReRandomizationSeedGen
Consumes the context to instantiate a seed generator