This module implements the generation of the client keys structs
Client keys are the keys used to encrypt an decrypt data. These are private and MUST NOT be shared.
Structs
- Client
Key - A structure containing the client key, which must be kept secret.
- CrtClient
Key - Client key “specialized” for CRT decomposition.
- Radix
Client Key - Client key “specialized” for radix decomposition.