pub struct KVStore<Key, Ct> { /* private fields */ }Expand description
The KVStore is a specialized encrypted HashMap
- Keys are clear numbers
- Values are RadixCiphertext or SignedRadixCiphertext
It supports getting/modifying existing pairs of (key,value) using an encrypted key.
To serialize a KVStore it must first be compressed with KVStore::compress
Implementations
Sourceimpl<Key, Ct> KVStore<Key, Ct>
impl<Key, Ct> KVStore<Key, Ct>
Sourcepub fn get(&self, key: &Key) -> Option<&Ct>where
Key: Ord,
pub fn get(&self, key: &Key) -> Option<&Ct>where
Key: Ord,
Returns the value stored for the key if any
Key is in clear, see ServerKey::kv_store_get if you wish to query using an encrypted key
Sourcepub fn get_mut(&mut self, key: &Key) -> Option<&mut Ct>where
Key: Ord,
pub fn get_mut(&mut self, key: &Key) -> Option<&mut Ct>where
Key: Ord,
Returns the value stored for the key if any
Key is in clear, see ServerKey::kv_store_get if you wish to query using an encrypted key
Sourcepub fn insert(&mut self, key: Key, value: Ct) -> Option<Ct>where
Key: Ord,
Ct: IntegerRadixCiphertext,
pub fn insert(&mut self, key: Key, value: Ct) -> Option<Ct>where
Key: Ord,
Ct: IntegerRadixCiphertext,
Sourcepub fn clear_get(&self, key: &Key) -> Option<&Ct>where
Key: Ord,
pub fn clear_get(&self, key: &Key) -> Option<&Ct>where
Key: Ord,
Returns the value associated to the key given in clear
pub fn contains_key(&self, key: &Key) -> boolwhere
Key: Ord,
pub fn iter(&self) -> impl Iterator<Item = (&Key, &Ct)>
Sourceimpl<Key, Ct> KVStore<Key, Ct>
impl<Key, Ct> KVStore<Key, Ct>
Sourcepub fn compress(
&self,
compression_key: &CompressionKey,
) -> CompressedKVStore<Key, Ct>
pub fn compress( &self, compression_key: &CompressionKey, ) -> CompressedKVStore<Key, Ct>
Compress the KVStore to be able to serialize it