pub enum ShortintBootstrappingKey<InputScalar>where
InputScalar: UnsignedInteger,{
Classic {
bsk: FourierLweBootstrapKeyOwned,
modulus_switch_noise_reduction_key: ModulusSwitchConfiguration<InputScalar>,
},
MultiBit {
fourier_bsk: FourierLweMultiBitBootstrapKeyOwned,
thread_count: ThreadCount,
deterministic_execution: bool,
},
}Variants
Classic
Fields

modulus_switch_noise_reduction_key: ModulusSwitchConfiguration<InputScalar>MultiBit
Implementations
Sourceimpl<InputScalar> ShortintBootstrappingKey<InputScalar>where
InputScalar: UnsignedInteger,
impl<InputScalar> ShortintBootstrappingKey<InputScalar>where
InputScalar: UnsignedInteger,
pub fn input_lwe_dimension(&self) -> LweDimension
pub fn polynomial_size(&self) -> PolynomialSize
pub fn glwe_size(&self) -> GlweSize
pub fn decomposition_base_log(&self) -> DecompositionBaseLog
pub fn decomposition_level_count(&self) -> DecompositionLevelCount
pub fn output_lwe_dimension(&self) -> LweDimension
pub fn bootstrapping_key_size_elements(&self) -> usize
pub fn bootstrapping_key_size_bytes(&self) -> usize
Sourcepub fn deterministic_pbs_execution(&self) -> bool
pub fn deterministic_pbs_execution(&self) -> bool
Indicate whether the PBS algorithm is deterministic, i.e. will produce the same bit-exact output when run twice on the same bit-exact input.
Note: the classic PBS algorithm is always deterministic.
Sourcepub fn set_deterministic_pbs_execution(
&mut self,
new_deterministic_execution: bool,
)
pub fn set_deterministic_pbs_execution( &mut self, new_deterministic_execution: bool, )
Set the choice of PBS algorithm to have the new_deterministic_execution behavior.
Note: the classic PBS algorithm is always deterministic and calling this function on a
ServerKey made from super::ClassicPBSParameters is a no-op.
Sourcepub fn recompute_thread_count(&mut self)
pub fn recompute_thread_count(&mut self)
Recomputes the number of threads required for the multi bit PBS.
It may be useful to call this function when the CPU usage is low and predictable to have a better value for the number of threads to use for the multi bit PBS.
Has not effects for other keys.
pub fn modulus_switch_configuration( &self, ) -> Option<&ModulusSwitchConfiguration<InputScalar>>