pub struct ClientKey { /* private fields */ }Available on crate features
boolean or shortint or integer only.Expand description
Key of the client
This struct contains the keys that are of interest to the user as they will allow to encrypt and decrypt data.
This key MUST NOT be sent to the server.
Implementations
sourceimpl ClientKey
impl ClientKey
pub fn generate_with_seed<C: Into<Config>>(config: C, seed: Seed) -> ClientKey
sourcepub fn generate_server_key(&self) -> ServerKey
pub fn generate_server_key(&self) -> ServerKey
Generates a new ServerKey
The ServerKey generated is meant to be used to initialize the global state
using crate::high_level_api::set_server_key.
sourcepub fn generate_compressed_server_key(&self) -> CompressedServerKey
pub fn generate_compressed_server_key(&self) -> CompressedServerKey
Generates a new CompressedServerKey