pub struct FheUint<Id: FheUintId> { /* private fields */ }Expand description
A Generic FHE unsigned integer
This struct is generic over some Id, as its the Id that controls how many bit they represent.
You will need to use one of this type specialization (e.g., FheUint8, FheUint12, FheUint16).
Its the type that overloads the operators (+, -, *),
since the FheUint type is not Copy the operators are also overloaded
to work with references.
Implementations
Sourceimpl<Id: FheUintId> FheUint<Id>
impl<Id: FheUintId> FheUint<Id>
Sourcepub fn generate_oblivious_pseudo_random(seed: impl OprfSeed) -> Self
pub fn generate_oblivious_pseudo_random(seed: impl OprfSeed) -> Self
Generates an encrypted unsigned integer taken uniformly in its full range using the given seed. The encrypted value is oblivious to the server. It can be useful to make server random generation deterministic.
use tfhe::prelude::FheDecrypt;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8, Seed};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
// DANGER: Using a deterministic seed is insecure and only done here to show API usage.
// The proper way of generating a seed depends on your application.
let ct_res = FheUint8::generate_oblivious_pseudo_random(Seed(0));
let dec_result: u16 = ct_res.decrypt(&client_key);Sourcepub fn get_generate_oblivious_pseudo_random_size_on_gpu() -> u64
pub fn get_generate_oblivious_pseudo_random_size_on_gpu() -> u64
Returns the amount of memory required to execute generate_oblivious_pseudo_random
use tfhe::core_crypto::gpu::check_valid_cuda_malloc_assert_oom;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8, GpuIndex};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let random_bits_count = 3;
let size = FheUint8::get_generate_oblivious_pseudo_random_size_on_gpu();
check_valid_cuda_malloc_assert_oom(size, GpuIndex::new(0));Sourcepub fn generate_oblivious_pseudo_random_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>(
seed: impl OprfSeed,
re_randomization_mode: RRD,
prf_re_randomization_context: &PrfReRandomizationContext,
) -> Result<Self>
pub fn generate_oblivious_pseudo_random_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>( seed: impl OprfSeed, re_randomization_mode: RRD, prf_re_randomization_context: &PrfReRandomizationContext, ) -> Result<Self>
Re-randomizing variant of Self::generate_oblivious_pseudo_random.
Sourcepub fn generate_oblivious_pseudo_random_bounded(
seed: impl OprfSeed,
random_bits_count: u64,
) -> Self
pub fn generate_oblivious_pseudo_random_bounded( seed: impl OprfSeed, random_bits_count: u64, ) -> Self
Generates an encrypted unsigned integer
taken uniformly in [0, 2^random_bits_count[ using the given seed.
The encrypted value is oblivious to the server.
It can be useful to make server random generation deterministic.
WARNING: If the requested random_bits_count is 0, then the returned ciphertext is a
trivial encryption of 0.
use tfhe::prelude::FheDecrypt;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8, Seed};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let random_bits_count = 3;
// DANGER: Using a deterministic seed is insecure and only done here to show API usage.
// The proper way of generating a seed depends on your application.
let ct_res = FheUint8::generate_oblivious_pseudo_random_bounded(Seed(0), random_bits_count);
let dec_result: u16 = ct_res.decrypt(&client_key);
assert!(dec_result < (1 << random_bits_count));Sourcepub fn generate_oblivious_pseudo_random_bounded_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>(
seed: impl OprfSeed,
random_bits_count: u64,
re_randomization_mode: RRD,
prf_re_randomization_context: &PrfReRandomizationContext,
) -> Result<Self>
pub fn generate_oblivious_pseudo_random_bounded_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>( seed: impl OprfSeed, random_bits_count: u64, re_randomization_mode: RRD, prf_re_randomization_context: &PrfReRandomizationContext, ) -> Result<Self>
Re-randomizing variant of Self::generate_oblivious_pseudo_random_bounded.
WARNING: If the requested random_bits_count is 0, then the returned ciphertext is a
trivial encryption of 0.
Sourcepub fn generate_oblivious_pseudo_random_custom_range(
seed: impl OprfSeed,
range: &RangeForRandom,
max_distance: Option<f64>,
) -> Self
pub fn generate_oblivious_pseudo_random_custom_range( seed: impl OprfSeed, range: &RangeForRandom, max_distance: Option<f64>, ) -> Self
Generates an encrypted unsigned integer
taken almost uniformly in the given range using the given seed.
Currently the range can only be in the form [0, excluded_upper_bound[
with any excluded_upper_bound in [1, 2^64[.
The encrypted value is oblivious to the server. It can be useful to make server random generation deterministic.
This function guarantees the the norm-1 distance
(defined as ∆(P,Q) := 1/2 Sum[ω∈Ω] |P(ω) − Q(ω)|)
between the actual distribution and the target uniform distribution
will be below the max_distance argument (which must be in ]0, 1[).
The higher the distance, the more dissimilar the actual distribution is
from the target uniform distribution.
The default value for max_distance is 2^-128 if None is provided.
Higher values allow better performance but must be considered carefully in the context of their target application as it may have serious unintended consequences.
If the range is a power of 2, the distribution is uniform (for any max_distance) and
the cost is smaller.
use std::num::NonZeroU64;
use tfhe::prelude::FheDecrypt;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8, RangeForRandom, Seed};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let excluded_upper_bound = NonZeroU64::new(3).unwrap();
let range = RangeForRandom::new_from_excluded_upper_bound(excluded_upper_bound);
// DANGER: Using a deterministic seed is insecure and only done here to show API usage.
// The proper way of generating a seed depends on your application.
let ct_res = FheUint8::generate_oblivious_pseudo_random_custom_range(Seed(0), &range, None);
let dec_result: u16 = ct_res.decrypt(&client_key);
assert!(dec_result < excluded_upper_bound.get() as u16);Sourcepub fn get_generate_oblivious_pseudo_random_bounded_size_on_gpu() -> u64
pub fn get_generate_oblivious_pseudo_random_bounded_size_on_gpu() -> u64
Returns the amount of memory required to execute generate_oblivious_pseudo_random_bounded
use tfhe::core_crypto::gpu::check_valid_cuda_malloc_assert_oom;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8, GpuIndex};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let random_bits_count = 3;
let size = FheUint8::get_generate_oblivious_pseudo_random_bounded_size_on_gpu();
check_valid_cuda_malloc_assert_oom(size, GpuIndex::new(0));Sourcepub fn generate_oblivious_pseudo_random_custom_range_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>(
seed: impl OprfSeed,
range: &RangeForRandom,
max_distance: Option<f64>,
re_randomization_mode: RRD,
prf_re_randomization_context: &PrfReRandomizationContext,
) -> Result<Self>
pub fn generate_oblivious_pseudo_random_custom_range_and_re_randomize<'a, RRD: Into<ReRandomizationMode<'a>>>( seed: impl OprfSeed, range: &RangeForRandom, max_distance: Option<f64>, re_randomization_mode: RRD, prf_re_randomization_context: &PrfReRandomizationContext, ) -> Result<Self>
Re-randomizing variant of Self::generate_oblivious_pseudo_random_custom_range.
Sourceimpl<Id> FheUint<Id>where
Id: FheUintId,
impl<Id> FheUint<Id>where
Id: FheUintId,
pub fn into_raw_parts( self, ) -> (RadixCiphertext, Id, Tag, ReRandomizationMetadata)
pub fn from_raw_parts( ciphertext: RadixCiphertext, id: Id, tag: Tag, re_randomization_metadata: ReRandomizationMetadata, ) -> Self
pub fn num_bits() -> usize
Sourcepub fn current_device(&self) -> Device
pub fn current_device(&self) -> Device
Returns the device where the ciphertext is currently on
Sourcepub fn move_to_device(&mut self, device: Device)
pub fn move_to_device(&mut self, device: Device)
Moves (in-place) the ciphertext to the desired device.
Does nothing if the ciphertext is already in the desired device
Sourcepub fn move_to_current_device(&mut self)
pub fn move_to_current_device(&mut self)
Moves (in-place) the ciphertext to the device of the current thread-local server key
Does nothing if the ciphertext is already in the desired device or if no server key is set
Sourcepub fn gpu_indexes(&self) -> &[GpuIndex]
pub fn gpu_indexes(&self) -> &[GpuIndex]
Returns the indexes of the GPUs where the ciphertext lives
If the ciphertext is on another deive (e.g CPU) then the returned slice is empty
Sourcepub fn is_even(&self) -> FheBool
pub fn is_even(&self) -> FheBool
Returns a FheBool that encrypts true if the value is even
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(32u16, &client_key);
let result = a.is_even();
let decrypted = result.decrypt(&client_key);
assert!(decrypted);Sourcepub fn is_odd(&self) -> FheBool
pub fn is_odd(&self) -> FheBool
Returns a FheBool that encrypts true if the value is odd
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(4393u16, &client_key);
let result = a.is_odd();
let decrypted = result.decrypt(&client_key);
assert!(decrypted);Sourcepub fn try_decrypt_trivial<Clear>(
&self,
) -> Result<Clear, NotTrivialCiphertextError>
pub fn try_decrypt_trivial<Clear>( &self, ) -> Result<Clear, NotTrivialCiphertextError>
Tries to decrypt a trivial ciphertext
Trivial ciphertexts are ciphertexts which are not encrypted meaning they can be decrypted by any key, or even without a key.
For debugging it can be useful to use trivial ciphertext to speed up execution, and use Self::try_decrypt_trivial to decrypt temporary values and debug.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
// This is not a trivial ciphertext as we use a client key to encrypt.
let non_trivial = FheUint16::encrypt(1u16, &client_key);
// This is a trivial ciphertext
let trivial = FheUint16::encrypt_trivial(2u16);
// We can trivial decrypt
let result: Result<u16, _> = trivial.try_decrypt_trivial();
assert_eq!(result, Ok(2));
// We cannot trivial decrypt
let result: Result<u16, _> = non_trivial.try_decrypt_trivial();
assert!(result.is_err());Sourcepub fn is_trivial(&self) -> bool
pub fn is_trivial(&self) -> bool
Returns true if the ciphertext is a trivial encryption
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let non_trivial = FheUint16::encrypt(1u16, &client_key);
assert!(!non_trivial.is_trivial());
let trivial = FheUint16::encrypt_trivial(2u16);
assert!(trivial.is_trivial());Sourcepub fn sum<'a, C>(collection: C) -> Selfwhere
C: AsRef<[&'a Self]>,
pub fn sum<'a, C>(collection: C) -> Selfwhere
C: AsRef<[&'a Self]>,
Sums multiple ciphertexts together.
This is much more efficient than manually calling the + operator, thus
using sum should always be preferred.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(1u16, &client_key);
let b = FheUint16::encrypt(2u16, &client_key);
let c = FheUint16::encrypt(3u16, &client_key);
let result = FheUint16::sum([&a, &b, &c]);
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 1u16 + 2 + 3);
// Or
let result = [&a, &b, &c].into_iter().sum::<FheUint16>();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 1u16 + 2 + 3);Sourcepub fn contains(cts: &[Self], value: &Self) -> FheBool
pub fn contains(cts: &[Self], value: &Self) -> FheBool
Returns an encrypted true if value is found in cts.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(1u16, &client_key);
let b = FheUint16::encrypt(2u16, &client_key);
let c = FheUint16::encrypt(3u16, &client_key);
let value = FheUint16::encrypt(2u16, &client_key);
let result = FheUint16::contains(&[a, b, c], &value);
let decrypted = result.decrypt(&client_key);
assert!(decrypted);Sourcepub fn leading_zeros(&self) -> FheUint32
pub fn leading_zeros(&self) -> FheUint32
Returns the number of leading zeros in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(0b00111111_11111111u16, &client_key);
let result = a.leading_zeros();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 2);Sourcepub fn leading_ones(&self) -> FheUint32
pub fn leading_ones(&self) -> FheUint32
Returns the number of leading ones in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(0b11000000_00000000u16, &client_key);
let result = a.leading_ones();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 2);Sourcepub fn trailing_zeros(&self) -> FheUint32
pub fn trailing_zeros(&self) -> FheUint32
Returns the number of trailing zeros in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(0b0000000_0101000u16, &client_key);
let result = a.trailing_zeros();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 3);Sourcepub fn trailing_ones(&self) -> FheUint32
pub fn trailing_ones(&self) -> FheUint32
Returns the number of trailing ones in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(0b0000000_0110111u16, &client_key);
let result = a.trailing_ones();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 3);Sourcepub fn count_ones(&self) -> FheUint32
pub fn count_ones(&self) -> FheUint32
Returns the number of ones in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let clear_a = 0b0000000_0110111u16;
let a = FheUint16::encrypt(clear_a, &client_key);
let result = a.count_ones();
let decrypted: u32 = result.decrypt(&client_key);
assert_eq!(decrypted, clear_a.count_ones());Sourcepub fn count_zeros(&self) -> FheUint32
pub fn count_zeros(&self) -> FheUint32
Returns the number of zeros in the binary representation of self.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let clear_a = 0b0000000_0110111u16;
let a = FheUint16::encrypt(clear_a, &client_key);
let result = a.count_zeros();
let decrypted: u32 = result.decrypt(&client_key);
assert_eq!(decrypted, clear_a.count_zeros());Sourcepub fn ilog2(&self) -> FheUint32
pub fn ilog2(&self) -> FheUint32
Returns the base 2 logarithm of the number, rounded down.
Result has no meaning if self encrypts 0. See Self::checked_ilog2
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(2u16, &client_key);
let result = a.ilog2();
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 1);Sourcepub fn checked_ilog2(&self) -> (FheUint32, FheBool)
pub fn checked_ilog2(&self) -> (FheUint32, FheBool)
Returns the base 2 logarithm of the number, rounded down.
Also returns a boolean flag that is true if the result is valid (i.e self was > 0)
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(0u16, &client_key);
let (result, is_ok) = a.checked_ilog2();
let is_ok = is_ok.decrypt(&client_key);
assert!(!is_ok);
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 63); // result is meaninglessSourcepub fn match_value<Clear, OutId>(
&self,
matches: &MatchValues<Clear>,
) -> Result<(FheUint<OutId>, FheBool)>
pub fn match_value<Clear, OutId>( &self, matches: &MatchValues<Clear>, ) -> Result<(FheUint<OutId>, FheBool)>
match an input value to an output value
- Input values are not required to span all possible values that
selfcould hold. And the output type can be different.
Returns a FheBool that encrypts true if the input self
matched one of the possible inputs
Example
use tfhe::prelude::*;
use tfhe::{
generate_keys, set_server_key, ConfigBuilder, FheUint16, FheUint8, MatchValues,
};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(17u16, &client_key);
let match_values = MatchValues::new(vec![
(0u16, 3u16),
(1u16, 3u16),
(2u16, 3u16),
(17u16, 25u16),
])
.unwrap();
let (result, matched): (FheUint8, _) = a.match_value(&match_values)
.unwrap(); // All possible output values fit in a u8
let matched = matched.decrypt(&client_key);
assert!(matched);
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 25u16)Sourcepub fn get_match_value_size_on_gpu<Clear>(
&self,
matches: &MatchValues<Clear>,
) -> Result<u64>
pub fn get_match_value_size_on_gpu<Clear>( &self, matches: &MatchValues<Clear>, ) -> Result<u64>
Returns the estimated memory usage (in bytes) required on the GPU to perform
the match_value operation.
This is useful to check if the operation fits in the GPU memory before attempting execution.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16, MatchValues};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let a = FheUint16::encrypt(17u16, &client_key);
let match_values = MatchValues::new(vec![(0u16, 3u16), (17u16, 25u16)]).unwrap();
#[cfg(feature = "gpu")]
{
let size_bytes = a.get_match_value_size_on_gpu(&match_values).unwrap();
println!("Memory required on GPU: {} bytes", size_bytes);
assert!(size_bytes > 0);
}Sourcepub fn match_value_or<Clear, OutId>(
&self,
matches: &MatchValues<Clear>,
or_value: Clear,
) -> Result<FheUint<OutId>>
pub fn match_value_or<Clear, OutId>( &self, matches: &MatchValues<Clear>, or_value: Clear, ) -> Result<FheUint<OutId>>
match an input value to an output value
- Input values are not required to span all possible values that
selfcould hold. And the output type can be different.
If none of the input matched the self then, self will encrypt the
value given to or_value
Example
use tfhe::prelude::*;
use tfhe::{
generate_keys, set_server_key, ConfigBuilder, FheUint16, FheUint8, MatchValues,
};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let a = FheUint16::encrypt(17u16, &client_key);
let match_values = MatchValues::new(vec![
(0u16, 3u16), // map 0 to 3
(1u16, 234u16),
(2u16, 123u16),
])
.unwrap();
let result: FheUint8 = a.match_value_or(&match_values, 25u16)
.unwrap(); // All possible output values fit on a u8
let decrypted: u16 = result.decrypt(&client_key);
assert_eq!(decrypted, 25u16)Sourcepub fn get_match_value_or_size_on_gpu<Clear>(
&self,
matches: &MatchValues<Clear>,
or_value: Clear,
) -> Result<u64>
pub fn get_match_value_or_size_on_gpu<Clear>( &self, matches: &MatchValues<Clear>, or_value: Clear, ) -> Result<u64>
Returns the estimated memory usage (in bytes) required on the GPU to perform
the match_value_or operation.
This is useful to check if the operation fits in the GPU memory before attempting execution.
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint16, MatchValues};
let config = ConfigBuilder::default().build();
let (client_key, server_key) = generate_keys(config);
set_server_key(server_key);
let a = FheUint16::encrypt(17u16, &client_key);
let match_values = MatchValues::new(vec![(0u16, 3u16), (17u16, 25u16)]).unwrap();
#[cfg(feature = "gpu")]
{
let size_bytes = a
.get_match_value_or_size_on_gpu(&match_values, 55u16)
.unwrap();
println!("Memory required on GPU: {} bytes", size_bytes);
assert!(size_bytes > 0);
}Sourcepub fn reverse_bits(&self) -> Self
pub fn reverse_bits(&self) -> Self
Reverse the bit of the unsigned integer
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheUint8};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let msg = 0b10110100_u8;
let a = FheUint8::encrypt(msg, &client_key);
let result: FheUint8 = a.reverse_bits();
let decrypted: u8 = result.decrypt(&client_key);
assert_eq!(decrypted, msg.reverse_bits());Sourcepub fn if_then_else<Clear>(
condition: &FheBool,
true_value: Clear,
false_value: Clear,
) -> Self
pub fn if_then_else<Clear>( condition: &FheBool, true_value: Clear, false_value: Clear, ) -> Self
Creates a FheUint that encrypts either of two values depending on an encrypted condition
Example
use tfhe::prelude::*;
use tfhe::{generate_keys, set_server_key, ConfigBuilder, FheBool, FheUint32};
let (client_key, server_key) = generate_keys(ConfigBuilder::default());
set_server_key(server_key);
let cond = FheBool::encrypt(true, &client_key);
let result = FheUint32::if_then_else(&cond, u32::MAX, u32::MIN);
let decrypted: u32 = result.decrypt(&client_key);
assert_eq!(decrypted, u32::MAX);
let result = FheUint32::if_then_else(&!cond, u32::MAX, u32::MIN);
let decrypted: u32 = result.decrypt(&client_key);
assert_eq!(decrypted, u32::MIN);Sourcepub fn select<Clear>(
condition: &FheBool,
true_value: Clear,
false_value: Clear,
) -> Self
pub fn select<Clear>( condition: &FheBool, true_value: Clear, false_value: Clear, ) -> Self
Same as Self::if_then_else but with a different name
Sourcepub fn cmux<Clear>(
condition: &FheBool,
true_value: Clear,
false_value: Clear,
) -> Self
pub fn cmux<Clear>( condition: &FheBool, true_value: Clear, false_value: Clear, ) -> Self
Same as Self::if_then_else but with a different name
pub fn re_randomization_metadata(&self) -> &ReRandomizationMetadata
pub fn re_randomization_metadata_mut(&mut self) -> &mut ReRandomizationMetadata