pub struct TranscipheringServerKey { /* private fields */ }Expand description
Key material of the transciphering subsystem.
Taking this rather than a plain OprfServerKey is what keeps the ciphers from drawing their
key material from the general purpose OPRF key or, through it, from the compute key.
Implementations
Sourceimpl TranscipheringServerKey
impl TranscipheringServerKey
pub fn new(sk: &TranscipheringPrivateKey, target_ck: &ClientKey) -> Result<Self>
pub fn oprf_key(&self) -> &OprfServerKey
pub fn from_raw_parts(oprf_key: OprfServerKey) -> Self
pub fn into_raw_parts(self) -> OprfServerKey